@@ -3,7 +3,7 @@
 # Programmer friendly subprocess wrapper.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: October 11, 2018
+# Last Change: March 2, 2020
 # URL: https://executor.readthedocs.io
 
 """
@@ -53,7 +53,7 @@ import sys
 import tempfile
 
 # External dependencies.
-from humanfriendly import compact, concatenate, format, pluralize
+from humanfriendly.text import compact, concatenate, format, pluralize
 from humanfriendly.terminal import connected_to_terminal
 from property_manager import (
     PropertyManager,
@@ -68,7 +68,7 @@ from six import string_types, text_type
 from executor.process import ControllableProcess
 
 # Semi-standard module versioning.
-__version__ = '21.2'
+__version__ = '22.0'
 
 # Initialize a logger.
 logger = logging.getLogger(__name__)
@@ -386,7 +386,7 @@ class ExternalCommand(ControllableProcess):
         example above, in order to keep it simple, but I did test it and
         it should actually work (at least it did for me):
 
-        .. code-block:: sh
+        .. code-block:: console
 
            $ export XSCREENSAVER_BLANK_COMMAND='echo $(date) - Screen is now blanked'
            $ export XSCREENSAVER_LOCK_COMMAND='echo $(date) - Screen is now locked'
@@ -2112,12 +2112,19 @@ def validate_ionice_class(value):
     Ensure that the given value is a valid I/O scheduling class for ionice_.
 
     :param value: The value to validate (a string).
-    :returns: The validated value (one of the strings 'idle',
-              'best-effort' or 'realtime').
+    :returns: The validated value (one of the strings '1', '2', '3', 'idle',
+              'best-effort', or 'realtime').
     :raises: :exc:`~exceptions.ValueError` when the given value isn't one of
              the strings mentioned above.
+
+    The strings 'idle', 'best-effort' and 'realtime' are preferred for
+    readability but not supported in minimalistic environments like busybox
+    which only support the values '1', '2' and '3' (refer to `#16`_). It's up
+    to the caller to choose the correct value, no translation is done.
+
+    .. _#16: https://github.com/xolox/python-executor/pull/16
     """
-    expected = ('idle', 'best-effort', 'realtime')
+    expected = ('idle', 'best-effort', 'realtime', '1', '2', '3')
     if value not in expected:
         msg = "Invalid I/O scheduling class! (got %r while valid options are %s)"
         raise ValueError(msg % (value, concatenate(expected)))
