@@ -1,7 +1,7 @@
 # Programmer friendly subprocess wrapper.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: October 7, 2018
+# Last Change: March 2, 2020
 # URL: https://executor.readthedocs.io
 
 """
@@ -24,7 +24,9 @@ import os
 # External dependencies.
 from executor import ExternalCommandFailed
 from executor import logger as parent_logger
-from humanfriendly import format, pluralize, Spinner, Timer
+from humanfriendly import Timer
+from humanfriendly.terminal.spinners import Spinner
+from humanfriendly.text import format, pluralize
 from property_manager import PropertyManager, mutable_property
 
 # Initialize a logger.
