@@ -1,7 +1,7 @@
 # Automated tests for the `executor' module.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: October 7, 2018
+# Last Change: March 2, 2020
 # URL: https://executor.readthedocs.io
 
 """
@@ -22,7 +22,7 @@ personal development environment I have added a custom sudo configuration file
 
     # To enable test_sudo_option.
     peter ALL=NOPASSWD:/bin/chmod 600 /tmp/executor-test-suite/*
-    peter ALL=NOPASSWD:/bin/chown root\:root /tmp/executor-test-suite/*
+    peter ALL=NOPASSWD:/bin/chown root\\:root /tmp/executor-test-suite/*
     peter ALL=NOPASSWD:/bin/rm -R /tmp/executor-test-suite
     peter ALL=NOPASSWD:/usr/bin/stat --format=%a /tmp/executor-test-suite/*
     peter ALL=NOPASSWD:/usr/bin/stat --format=%G /tmp/executor-test-suite/*
@@ -55,8 +55,9 @@ import time
 import uuid
 
 # External dependencies.
-from humanfriendly import Timer, coerce_boolean, compact, dedent
+from humanfriendly import Timer, coerce_boolean
 from humanfriendly.testing import TemporaryDirectory, TestCase, retry, run_cli
+from humanfriendly.text import compact, dedent
 from mock import MagicMock
 from property_manager import set_property
 from six.moves import StringIO
@@ -70,6 +71,7 @@ from executor import (
     ExternalCommand,
     ExternalCommandFailed,
     execute,
+    validate_ionice_class,
     quote,
     which,
 )
@@ -204,14 +206,20 @@ class ExecutorTestCase(TestCase):
         assert execute('true') is True
         assert execute('false', check=False) is False
         # Make sure execute('false') raises an exception.
-        self.assertRaises(ExternalCommandFailed, execute, 'false')
+        with self.assertRaises(ExternalCommandFailed):
+            execute('false')
         # Make sure execute('exit 42') raises an exception.
-        shell_cmd = 'echo -n what; echo -n ever; exit 42'
-        e = self.assertRaises(ExternalCommandFailed, execute, shell_cmd, silent=True)
+        with self.assertRaises(ExternalCommandFailed):
+            execute('exit 42')
         # Make sure the exception has the expected properties.
-        self.assertEqual(e.command.command_line, ['bash', '-c', shell_cmd])
-        self.assertEqual(e.returncode, 42)
-        self.assertTrue('whatever' in e.error_message)
+        try:
+            shell_cmd = 'echo -n what; echo -n ever; exit 42'
+            execute(shell_cmd, silent=True)
+            assert False, "This code should not be reached!"
+        except ExternalCommandFailed as e:
+            self.assertEqual(e.command.command_line, ['bash', '-c', shell_cmd])
+            self.assertEqual(e.returncode, 42)
+            self.assertTrue('whatever' in e.error_message)
         # Make sure the CommandNotFound exception is raised consistently
         # regardless of the values of the `shell' and `asynchronous' options.
         for asynchronous in True, False:
@@ -494,19 +502,29 @@ class ExecutorTestCase(TestCase):
 
     def test_ionice_option(self):
         """Make sure ``ionice`` can be used."""
-        rsync_command_line = ['rsync', '-a', '/', '/mnt/backups/latest/']
-        expected_ionice_command = ['ionice', '-c', 'idle']
-        command = ExternalCommand(*rsync_command_line, ionice='idle')
-        assert command.ionice == 'idle'
-        print(command.ionice_command)
-        assert command.ionice_command == expected_ionice_command
-        assert command.command_line == (expected_ionice_command + rsync_command_line)
-        self.assertRaises(
-            ValueError,
-            ExternalCommand,
-            'touch', 'something-inappropriate',
-            ionice='unknown-class',
-        )
+        for value in '1', '2', '3', 'idle', 'best-effort', 'realtime':
+            rsync_command_line = ['rsync', '-a', '/', '/mnt/backups/latest/']
+            expected_ionice_command = ['ionice', '-c', value]
+            command = ExternalCommand(*rsync_command_line, ionice=value)
+            assert command.ionice == value
+            assert command.ionice_command == expected_ionice_command
+            assert command.command_line == (expected_ionice_command + rsync_command_line)
+            self.assertRaises(
+                ValueError,
+                ExternalCommand,
+                'touch', 'something-inappropriate',
+                ionice='unknown-class',
+            )
+
+    def test_ionice_validation(self):
+        """Test the validation of ionice arguments."""
+        # Ensure that invalid values are refused.
+        self.assertRaises(ValueError, validate_ionice_class, 'not a valid choice')
+        self.assertRaises(ValueError, validate_ionice_class, '0')
+        self.assertRaises(ValueError, validate_ionice_class, '4')
+        # Ensure that valid values are accepted.
+        for value in 'idle', 'best-effort', 'realtime', '1', '2', '3':
+            validate_ionice_class(value)
 
     def test_environment_variable_handling(self):
         """Make sure environment variables can be overridden."""
